@@ -3,9 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play the tabla!
 
-our $VERSION = '0.0106';
-
-use lib map { "$ENV{HOME}/sandbox/$_/lib" } qw(MIDI-Util MIDI-Drummer-Tiny);
+our $VERSION = '0.0200';
 
 use Moo;
 use File::Slurper qw(write_text);
@@ -156,28 +154,6 @@ sub _double_strike {
     $self->note($dura, $pitch1, $pitch2);
 }
 
-
-sub timidity_conf {
-    my ($self, $filename) = @_;
-    my $soundfont = $self->soundfont;
-    my $config = <<"CONF";
-# https://gleitz.github.io/midi-js-soundfonts/
-soundfont $soundfont
-CONF
-    write_text($filename, $config) if $filename;
-    return $config;
-}
-
-
-sub play_timidity {
-    my ($self, $filename) = @_;
-    $filename ||= './timidity-tabla.cfg';
-    $self->timidity_conf($filename);
-    $self->write;
-    my @cmd = ('timidity', '-c', $filename, $self->file);
-    system(@cmd) == 0 or die "system(@cmd) failed: $?";
-}
-
 1;
 
 __END__
@@ -192,7 +168,7 @@ Music::Percussion::Tabla - Play the tabla!
 
 =head1 VERSION
 
-version 0.0106
+version 0.0200
 
 =head1 SYNOPSIS
 
@@ -210,11 +186,11 @@ version 0.0106
 
   say $tabla->soundfont;
 
-  $tabla->timidity_conf('/tmp/timidity.cfg'); # save the cfg
+  $tabla->timidity_cfg('/tmp/timidity.cfg'); # save the cfg
   $tabla->write; # save the score as a MIDI file
 
   # OR:
-  $tabla->play_timidity; # play the score with timidity
+  $tabla->play_with_timidity; # play the score with timidity
 
 =head1 DESCRIPTION
 
@@ -423,24 +399,6 @@ Baya bol: dhin = C<ga> + C<tin>
 
 Baya bol: tirkit = C<tete> + C<ka> + C<te>
 
-=head2 timidity_conf
-
-  $timidity_conf = $tabla->timidity_conf;
-  $tabla->timidity_conf($filename);
-
-A suggested timidity.cfg paragraph to allow you to use this soundfont
-in timidity. If a B<filename> is given, the timidity configuration is
-written to that file.
-
-=head2 play_timidity
-
-  $tabla->play_timidity;
-  $tabla->play_timidity($filename);
-
-Play the tabla score with timidity. If a B<filename> is given, it is
-used for the timidity configuration. Otherwise a filename of
-C<timidity-tabla.cfg> is used.
-
 =head1 SEE ALSO
 
 L<File::Slurper>
